@@ -35,6 +35,7 @@
 #include "htmltable.h"
 #include "htmltablecell.h"
 #include "htmltablepriv.h"
+#include "htmlselection.h"
 #include "htmlundo.h"
 
 HTMLTable *
@@ -430,8 +431,11 @@ html_table_delete_column (HTMLTable *t, HTMLEngine *e, gint col, HTMLUndoDirecti
 void
 html_engine_delete_table_column (HTMLEngine *e)
 {
-	HTMLTableCell *cell = html_engine_get_table_cell (e);
+	HTMLTableCell *cell;
 
+	html_engine_disable_selection (e);
+
+	cell = html_engine_get_table_cell (e);
 	if (cell)
 		html_table_delete_column (html_engine_get_table (e), e, cell->col, HTML_UNDO_UNDO);
 }
@@ -629,8 +633,11 @@ html_table_delete_row (HTMLTable *t, HTMLEngine *e, gint row, HTMLUndoDirection
 void
 html_engine_delete_table_row (HTMLEngine *e)
 {
-	HTMLTableCell *cell = html_engine_get_table_cell (e);
+	HTMLTableCell *cell;
 
+	html_engine_disable_selection (e);
+
+	cell = html_engine_get_table_cell (e);
 	if (cell)
 		html_table_delete_row (html_engine_get_table (e), e, cell->row, HTML_UNDO_UNDO);
 }
@@ -1133,6 +1140,8 @@ html_engine_delete_table (HTMLEngine *e)
 {
 	HTMLTable *table;
 
+	html_engine_disable_selection (e);
+
 	table = html_engine_get_table (e);
 
 	if (!table)
